#!/usr/bin/env python3
#Mupen64Plus launcher to make configuration and game selection easier
#Marcus Dean Adams (marcusdean.adams@gmail.com)
#26 October 2015

#Initialize some variables
ver = "Marcus's Mupen64Plus Launcher 15.10.26"

#Import necessary libraries
from easygui import *
import os, initial, datetime, subprocess, sys

if os.name is not "posix":
	notnix = indexbox(msg="This program only works on Linux systems.  Mupen64Plus for Windows is a royal pain to get set up with something like this that is supposed to make things easier because it doesn't assume any defaults.  If you would like to use a good Nintendo 64 emulator on your Windows machine that has a GUI, I recommend checking out Project64 at: http://www.pj64-emu.com", title=ver, choices=('OK', 'Go to Project 64 Web Page'))
	if notnix == 0:
		exit(0)
	if notnix == 1:
		os.system( '"C:\Program Files\Internet Explorer\iexplore.exe" http://www.pj64-emu.com' )
		exit(0)

#Checks to see if the initial configuration has been stored in the config
#file, and runs it if it hasn't.


if initial.initial == "false":
	
	msg = "It does not appear that you have configured this program yet.  The following dialogs will walk you through the process of doing the initial configuration.  If you would like to re-run the configuration at any time, you can either run the file reconfigure.py, or you can edit the config.py file yourself."
	
	#Configures the Mupen64 install directory
	msg = "We need to know where Mupen64Plus is installed to.  In the next dialog, please select the folder where we can find the mupen64plus executable.  You can exit at any time by clicking the Cancel button."
	if ccbox( msg=msg, title=ver ):
		pass
	else:
		exit(0)
	gamedir = diropenbox( "Select the folder where you have Mupen64Plus installed", default=os.environ['HOME'] )
	if gamedir:
		pass
	else:
		exit(0)
	
	#Configures the ROMs directory
	msg = "We need to know where you keep your N64 ROMs.  In the next dialog, select the folder where you store your ROMs."
	if ccbox( msg=msg, title=ver ):
		pass
	else:
		exit(0)
	romdir = diropenbox( title="Select the folder where you keep your ROMs", default=os.environ['HOME'] )
	if romdir:
		pass
	else:
		exit(0)
	
	#Configures the screen resolution and whether to run full screen
	#or windowed
	msg = "What resolution would like to run your games at?\nExample: 1024x768"
	res = enterbox( msg=msg, title=ver )
	if res:
		pass
	else:
		exit(0)
	
	msg = "Fullscreen or windowed mode?"
	size = indexbox( msg=msg, title=ver, choices=( 'Fullscreen', 'Windowed', 'Cancel' ) )
	if size == 0:
		size = "fullscreen"
	if size == 1:
		size = "windowed"
	if size == 2:
		exit(0)
		
	#Requests which graphics engine to use
	msg = "Which video plugin would you like to use?  If you are unsure, then try one out and see how it works.  If you want to point to a specific plugin file, click 'Custom' and point to the plugin file.  If you don't like it, you can always run the 'reconfigure.py' program to pick a different one."
	gfx = indexbox( msg=msg, title=ver, choices=( 'Glide64MK2', 'Rice Video', 'Custom', 'Cancel' ) )
	if gfx == 0:
		gfx = "mupen64plus-video-glide64mk2.so"
	if gfx == 1:
		gfx = "mupen64plus-video-rice.so"
	if gfx == 2:
		gfx = fileopenbox( title="Select the graphics plugin to use", default="%s/"%( gamedir ), filetypes = ["*.so"], )
		if gfx:
			pass
		else:
			exit(0)
	if size == 3:
		exit(0)
	
	#Writes all of the information gathered to a config file
	msg = "You have entered the following settings:\n\nMupen64Plus Install Folder: %s\n\nN64 ROMs Folder: %s\n\nResolution: %s\n\nScreen Type: %s\n\nVideo Plugin: %s\n\nTo accept these values just click Continue.  If you want to change any of these settings at a later date, for example if you get a different screen and need to change the resolution, you can either run the 'reconfigure.py' program, or you can open the 'config.py' file yourself and edit the settings there."%( gamedir, romdir, res, size, gfx )
	summary = indexbox( msg=msg, title=ver, choices=( 'Continue', 'Cancel' ) )
	if summary == 0:
		pass
	else:
		exit(0)
		
	#Writes everything to the config file
	commit = open("config.py", "w")
	commit.write( "#This is just a file for storing the configuration of the program.\n\n" )
	commit.write( "#Marcus Dean Adams (marcusdean.adams@gmail.com\n#All variable values should be contained in quotes\n\n" )
	commit.write( "#Screen Resolution\n\n#Values should be entered in the following format: WidthxHeight\n#Example: 1024x768\nres = '%s'\n\n"%(res) )
	commit.write( "#ROMs Folder\n\n#There's no need to add a backslash to the end of this path\nromdir = '%s'\n\n"%(romdir) )
	commit.write( "#Mupen64Plus Directory\n\n#There's no need to add a backslash to the end of this path\ngamedir = '%s'\n\n"%(gamedir) )
	commit.write( "#Screen type\n\n#Valid values are \"fullscreen\" and \"windowed\", must be all lowercase.\nscreentype = '%s'\n\n"%(size))
	commit.write( "#Video plugin\n\n#The filename of the video plugin file.  If you wish to use a plugin\n#that is not located in the Mupen64Plus install directory, you must\n#specify the full path to the plugin file.\ngfx = '%s'\n"%(gfx) )
	commit.close()
	
	commit = open( 'initial.py', 'w' )
	commit.write( "#The whole purpose of this is to determine whether or not the\n" )
	commit.write( "#initial configuration has been run.\n\n" )
	commit.write( "initial = 'true' " )
	commit.close()

#Imports config, waited until now just in case the initial setup runs and the contents of the config changes
import config

#Executes the appropriate commands
game = fileopenbox( title="Select the game you wish to play", default="%s/"%( config.romdir ) )
if game:
	pass
else:
	exit(0)
log = open( os.environ [ 'HOME' ] + "/mupen64plus-log.txt", 'w' )
time = datetime.datetime.now()
log.write( "%s\n\n"%( time ) )
log.write( "This log file generated by Marcus Adams's Mupen64Plus launcher\n\n" )
log.close()
exe = os.system( "cd '%s' && ./mupen64plus --gfx '%s' --resolution '%s' --'%s' '%s' >> $HOME/mupen64plus-log.txt"%( config.gamedir, config.gfx, config.res, config.screentype, game ) )

#Error handling
if exe != 0:
	if exe == 32512 or exe == 512:
		msgbox ( msg = "We failed to launch Mupen64Plus.  Please make sure you have the correct location of the Mupen64Plus executable configured in the config.py file.  You can either modify the entry yourself, or run the reconfigure.py program to enter the correct location.", title = ver, image = "images/failure.gif" )

	elif exe == 2560:
		badrom = indexbox ( msg = "We failed to launch the game you selected.  This can happen if the ROM file is corrupt, or if it is not a valid Nintendo 64 game.  N64 game files usually end with .z64, .n64, or .v64 .  For a current list of supported file types please visit the website for Mupen64Plus.\n\nAs always the log file may contain more details about what exactly happened.", title = ver, image = "images/failure.gif", choices = ( "Visit Mupen64Plus Website", "View Log File", "Exit" ) )
		if badrom == 0:
			os.system ( "sensible-browser 'http://www.mupen64plus.org/'" )
		elif badrom == 1:
			f = open ( os.environ [ 'HOME' ] + "/mupen64plus-log.txt", "r" )
			txt = f.readlines()
			f.close()
			codebox ( msg = "Below is the contents of the log file saved to your home folder.  This output is generated by Mupen64Plus and may give you some more detailed insight into the nature of the issue you are having.  Remember that this log file is saved to your home folder as: mupen64plus-log.txt", title = ver, text = txt )
		elif badrom == 2:
			exit(0)

	elif exe == 3072:
		badvideo = indexbox ( msg = "It appears that you have selected an invalid video plugin.  This can happen if you select the option to choose a custom video plugin and Mupen64Plus doesn't take a liking to what you chose, or if the video plugin you selected has been moved or deleted.  Please run the reconfigure.py program and choose a valid video plugin.  If you're curious, the details of the failure should be stored in the log file in your home folder named mupen64plus-log.txt", title = ver, image = "images/failure.gif", choices = ( "View Log File", "Exit" ) )
		if badvideo == 0:
			f = open ( os.environ [ 'HOME' ] + "/mupen64plus-log.txt", "r" )
			txt = f.readlines()
			f.close()
			codebox ( msg = "Below is the contents of the log file saved to your home folder.  This output is generated by Mupen64Plus and may give you some more detailed insight into the nature of the issue you are having.  Remember that this log file is saved to your home folder as: mupen64plus-log.txt", title = ver, text = txt )
		elif badvideo == 1:
			exit(0)
			
	else:
		idono = indexbox ( msg = "An unknown error has occurred.  The terminal window in the back may have some helpful details about the issue, or you can click the 'View Log File' button below to view the contents of the log file stored in your home folder.", title = ver, image = "images/failure.gif", choices = ( "View Log File", "Exit" ) )
		if idono == 0:
			f = open ( os.environ [ 'HOME' ] + "/mupen64plus-log.txt", "r" )
			txt = f.readlines()
			f.close()
			codebox ( msg = "Below is the contents of the log file saved to your home folder.  This output is generated by Mupen64Plus and may give you some more detailed insight into the nature of the issue you are having.  Remember that this log file is saved to your home folder as: mupen64plus-log.txt", title = ver, text = txt )
		else:
			exit(0)

exit(0)
