#!/bin/bash
#Mupen64Plus front-end to make game selection easier
#Marcus Dean Adams (marcusdean.adams@gmail.com)
#20 October 2013

#Checks for the Mupen64Plus install directory
gamedir=`sed -n '8{p;q}' config.txt`
if [ "$gamedir" = "" ];
then
	zenity --info --title="Mupen64Plus" --text="We need to know where Mupen64Plus is installed to.  In the next dialog, please select the folder where we can find the mupen64plus executable." || exit
	gamedir=$(zenity --file-selection --directory --title="Choose your Mupen64Plus install folder") || exit
	gamedir="$gamedir/"
	printf '%s\n' 8c "$gamedir" . w | ed -s config.txt
fi

#Checks for and sets the directory to search ROMs for
romdir=`sed -n '5{p;q}' config.txt`
if [ "$romdir" = "" ];
then
	zenity --info --title="Mupen64Plus" --text="You have not selected a ROMs folder.  In the next dialog, please choose the folder you keep your ROMs in." || exit
	romdir=$(zenity --file-selection --directory --title="Choose your ROMs folder") || exit
	romdir="$romdir/"
	printf '%s\n' 5c "$romdir" . w | ed -s config.txt
fi

#Sets the resolution by checking the contents of the text file, and prompting for a resolution to use if the file is empty
resolution=`sed -n '2{p;q}' config.txt`
if [ "$resolution" = "" ];
then
	resolution=$(zenity --entry --title="Mupen64Plus" --text="You don't appear to have a resolution configured, please enter your desired fullscreen resolution below.") || exit
	printf '%s\n' 2c "$resolution" . w | ed -s config.txt
fi

#Checks to see if the user has been told about the log file, and displays a message in case they have not
loginfo=`sed -n '11{p;q}' config.txt`
if [ "$loginfo" = "false" ];
then
	#Zenity info windows have a minimum height, and get ridiculously tall with messages more than a sentence or two long, so I broke it up into 3 separate dialogs.
	#May replace Zenity with something better later on, but at least this kind of forces users to read these dialogs.
	zenity --info --title="Mupen64Plus" --text="The following dialogs contain important information, and only run the first time you execute this script." ||exit
	zenity --info --title="Mupen64Plus" --text="A log file named mupen64plus-log.txt will be placed in your home directory every time you launch a game, so if you experience problems later with a game, please refer to that log file to find out what happened." || exit
	zenity --info --title="Mupen64Plus" --text="Please note that this script looks specifically for the Glide64 plugin file named mupen64plus-video-glide64mk2.so, so if you wish to use a different plugin, or if that plugin file has been renamed, you will have to edit line 55 of this script to point to the correct video plugin file." || exit
	zenity --info --title="Mupen64Plus" --text="For more information on this script, please refer to the Readme.txt file that shipped with it." || exit
	printf '%s\n' 11c "true" . w | ed -s config.txt
fi

#Asks the user to select a ROM file to use
game=$(zenity --file-selection --filename="$romdir" --title="Select a ROM to play") || exit

#Sets up log file date and time in case there are any issues with running a game so you can go back and look at it
date > $HOME/mupen64plus-log.txt
echo "" >> $HOME/mupen64plus-log.txt
echo "" >> $HOME/mupen64plus-log.txt
echo "This log file has been generated by Marcus Adams's Mupen64Plus script." >> $HOME/mupen64plus-log.txt
echo "" >> $HOME/mupen64plus-log.txt
echo "" >> $HOME/mupen64plus-log.txt

#Executes the game with the variables provided
cd $gamedir
./mupen64plus --fullescreen --gfx mupen64plus-video-glide64mk2.so --resolution $resolution "$game" >> $HOME/mupen64plus-log.txt

exit
